<?php
/*
Plugin Name: SEATEXT FREE Translation and Conversion Rate Boost
Description: Seatext AI translates your website for FREE plus AI grows conversion rate of your website +35% more sales for your website  
Version: 3.0.1
Author: Seatext.com
License: GPLv2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
*/

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

// Function to log messages to the database
function seatext_log($message) {
    global $wpdb;
    $table_name = $wpdb->prefix . 'seatext_log';
    
    // Create the table if it doesn't exist
    if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {
        $charset_collate = $wpdb->get_charset_collate();
        $sql = "CREATE TABLE $table_name (
            id mediumint(9) NOT NULL AUTO_INCREMENT,
            time datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
            message text NOT NULL,
            PRIMARY KEY  (id)
        ) $charset_collate;";
        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);
        
        if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {
            seatext_log('Failed to create log table');
            return;
        }
    }

    $wpdb->insert(
        $table_name,
        array(
            'time' => current_time('mysql'),
            'message' => $message
        )
    );
}

// Function to get the Seatext log from the database
function seatext_get_log() {
    if (!current_user_can('manage_options')) {
        return 'Access denied';
    }

    global $wpdb;
    $table_name = $wpdb->prefix . 'seatext_log';

    $results = $wpdb->get_results("SELECT time, message FROM $table_name ORDER BY time DESC LIMIT 100");

    if (empty($results)) {
        return "No log entries found";
    }

    $log = "";
    foreach ($results as $row) {
        $log .= "[{$row->time}] {$row->message}\n";
    }

    return $log;
}

// Activation hook
register_activation_hook(__FILE__, 'seatext_activate');

function seatext_activate() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'seatext_log';
    $charset_collate = $wpdb->get_charset_collate();
    $sql = "CREATE TABLE IF NOT EXISTS $table_name (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
        time datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
        message text NOT NULL,
        PRIMARY KEY  (id)
    ) $charset_collate;";
    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($sql);

    try {
        $existing_id = get_option('seatext_id');
        if ($existing_id) {
            seatext_log('Existing Seatext ID found: ' . $existing_id);
            return;
        }

        $site_url = get_site_url();
        $admin_email = get_option('admin_email');

        if ($site_url && $admin_email) {
            seatext_log('Generating ID from site URL and admin email');
            $seatext_id = 'wordpress_' . seatext_generate_url_safe_id_from_data($site_url . $admin_email);
        } else {
            seatext_log('Generating random ID');
            $seatext_id = 'wordpress_' . seatext_generate_url_safe_id(16);
        }

        seatext_log('Generated ID: ' . $seatext_id);

        update_option('seatext_id', $seatext_id);
        seatext_log('ID saved to options');

        seatext_log('Activation completed successfully');
    } catch (Exception $e) {
        seatext_log('Activation error: ' . $e->getMessage());
    }
}

// Function to generate a URL-safe ID from data (e.g., site URL and admin email)
function seatext_generate_url_safe_id_from_data($data) {
    seatext_log('Generating URL-safe ID from data');
    return substr(preg_replace('/[^a-zA-Z0-9]/', '', base64_encode(md5($data))), 0, 16); 
}

// Function to generate a random URL-safe ID starting with "wordpress-"
function seatext_generate_url_safe_id($length = 16) {
    seatext_log('Generating random URL-safe ID');
    $prefix = 'wordpress';
    $characters = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789';
    $id = $prefix;
    $random_length = $length - strlen($prefix);
    for ($i = 0; $i < $random_length; $i++) {
        $id .= $characters[wp_rand(0, strlen($characters) - 1)];
    }
    return $id;
}

// Fallback activation check
add_action('plugins_loaded', 'seatext_check_activation');

function seatext_check_activation() {
    if (!get_option('seatext_activated')) {
        seatext_activate();
        update_option('seatext_activated', true);
    }
}

// Uninstall hook
function seatext_uninstall() {
    // Remove only the 'seatext_activated' option
    delete_option('seatext_activated');

    // Log the uninstallation (since we're keeping the log table)
    seatext_log('Plugin uninstalled');

    // Any other cleanup code... as if user will reinstall seatext we need ot be sure that id stay not changed. This is needed as we keep trasnlations on our server, and user may not want to delete  link to them if he reinstalls plugin.
}

register_uninstall_hook(__FILE__, 'seatext_uninstall');




/////Here we use local seatext.js code, and we cant update it anymore - only will be udated when we update wordpress plug in.
function seatext_enqueue_scripts() {
    $seatext_id = get_option('seatext_id', '');

    // Original script enqueue with ID in URL
    wp_enqueue_script('seatext-script', plugins_url('seatext.js?id=' . urlencode($seatext_id), __FILE__), array('jquery'), null, true);

    // Data for wp_localize_script
    $script_data = array(
        'seatextId' => esc_js($seatext_id),
        'url' => esc_url(home_url('/')),
        'device' => wp_is_mobile() ? 'mobile' : 'desktop',
        'time' => esc_js(current_time('mysql', 1)),
        'lang' => esc_js(get_bloginfo('language')),
        'tz' => esc_js(get_option('timezone_string')),
        'ref' => esc_js(wp_get_referer()),
        'debug' => WP_DEBUG ? 'true' : 'false'
    );
    wp_localize_script('seatext-script', 'seatextData', $script_data);

    // New script enqueue for AJAX-based ID loading
    wp_enqueue_script('seatext-id-script', admin_url('admin-ajax.php') . '?action=seatext_id', array('seatext-script'), null, true);
}

function seatext_inline_fallback() {
    $seatext_id = get_option('seatext_id', '');
    echo "<script>
        if (typeof seatextData === 'undefined') {
            var script = document.createElement('script');
            script.src = '" . plugins_url('seatext.js?id=' . urlencode($seatext_id), __FILE__) . "';
            document.body.appendChild(script);
            window.seatextData = {
                seatextId: '" . esc_js($seatext_id) . "',
                url: '" . esc_url(home_url('/')) . "',
                device: '" . (wp_is_mobile() ? 'mobile' : 'desktop') . "',
                time: '" . esc_js(current_time('mysql', 1)) . "',
                lang: '" . esc_js(get_bloginfo('language')) . "',
                tz: '" . esc_js(get_option('timezone_string')) . "',
                ref: '" . esc_js(wp_get_referer()) . "',
                debug: '" . (WP_DEBUG ? 'true' : 'false') . "'
            };
        }
    </script>";
}

function seatext_id_script() {
    $seatext_id = get_option('seatext_id', '');
    header('Content-Type: application/javascript');
    echo "window.seatextId = " . json_encode($seatext_id) . ";";
    exit;
}


// These two lines are all we need for the AJAX action, regardless of theme or page builder
add_action('wp_ajax_nopriv_seatext_id', 'seatext_id_script');
add_action('wp_ajax_seatext_id', 'seatext_id_script');


// Standard WordPress with multiple priorities 
add_action('wp_enqueue_scripts', 'seatext_enqueue_scripts', 999);
add_action('wp_enqueue_scripts', 'seatext_enqueue_scripts', 20); // For Divi, Avada themes
add_action('wp_footer', 'seatext_enqueue_scripts', 999);
add_action('wp_footer', 'seatext_inline_fallback', 9999);

// WooCommerce hooks
add_action('woocommerce_after_main_content', 'seatext_enqueue_scripts', 999);
add_action('woocommerce_before_main_content', 'seatext_enqueue_scripts', 999);

// Page builder hooks
add_action('elementor/frontend/after_enqueue_scripts', 'seatext_enqueue_scripts', 999);
add_action('elementor/frontend/before_enqueue_scripts', 'seatext_enqueue_scripts', 999);


// Add settings link on plugin page
function seatext_settings_link($links) {
    $settings_link = '<a href="' . esc_url(admin_url('admin.php?page=seatext-settings')) . '">Settings</a>';
    array_unshift($links, $settings_link);
    return $links;
}

$plugin = plugin_basename(__FILE__);
add_filter("plugin_action_links_$plugin", 'seatext_settings_link');

// Add admin menu
function seatext_add_admin_menu() {
    add_menu_page('Seatext AI Settings', 'Seatext AI', 'manage_options', 'seatext-settings', 'seatext_render_settings_page', 'dashicons-translation');
}
add_action('admin_menu', 'seatext_add_admin_menu');

// Deactivation hook
register_deactivation_hook(__FILE__, 'seatext_deactivate');

function seatext_deactivate() {
    seatext_log('Plugin deactivated');
    delete_option('seatext_activated');
}

function seatext_admin_enqueue_scripts($hook) {
    if ('toplevel_page_seatext-settings' !== $hook) {
        return;
    }
    wp_enqueue_style('seatext-admin-style', plugins_url('css/admin-style.css', __FILE__));
    wp_enqueue_script('seatext-admin-script');
}
add_action('admin_enqueue_scripts', 'seatext_admin_enqueue_scripts');

function seatext_render_settings_page() {
    $seatext_id = get_option('seatext_id', '');
    $seatext_url = 'https://login.seatext.com/?seatextId=' . urlencode($seatext_id);
    $seatext_settings_url = 'https://login.seatext.com/welcome/aimanager';
    
    ?>
    <div class="wrap seatext-settings-page">
        <div class="seatext-header">
            <h2 class="seatext-title seatext-main-title"><?php echo esc_html('Welcome to SEATEXT AI, the first AI for websites.'); ?></h2>
            <div class="seatext-buttons">
                <button class="seatext-button" data-url="<?php echo esc_url($seatext_url); ?>">
                    <span class="dashicons dashicons-admin-users"></span> 
                    <?php echo esc_html('Register at Seatext.com'); ?>
                </button>
                <button class="seatext-button" data-url="<?php echo esc_url($seatext_settings_url); ?>">
                    <span class="dashicons dashicons-admin-generic"></span>
                    <?php echo esc_html('Manage AI Settings'); ?>
                </button>
                <p class="button-explanation">
                    <?php echo esc_html('Click "Register" to create your Seatext account and activate the plugin. After connecting your website, use "Manage AI Settings" to configure AI models, customize text variations, and track your progress.'); ?>
                </p>
            </div>
        </div>

        <div class="seatext-products">
            <?php
            $products = [
                [
                    'title' => 'Free, Unlimited Translations',
                    'description' => 'Translate your entire website to 125 languages at no cost, regardless of traffic volume or page count. SEATEXT AI is the only website translation system that A/B tests translations, eliminating mistakes and boosting international sales by +35%.',
                    'image' => 'picture-1.png',
                    'alt' => 'Translation'
                ],
                [
                    'title' => 'AI-Driven Conversion Rate Optimization',
                    'description' => 'Amazon runs 12,000 A/B tests each year to identify the most effective copy. SEATEXT AI replicates Amazon\'s approach by automatically generating thousands of text variations of your website copy and A/B testing them on a small portion of your website visitors. Once SEATEXT AI identifies the winning copy, it prioritizes showing it to your visitors, improving your website\'s sales and conversion rate.',
                    'image' => 'picture-2.png',
                    'alt' => 'CRO'
                ],
                [
                    'title' => 'AI-Optimized Product Descriptions',
                    'description' => 'FOR ONLINE STORES SEATEXT AI fine-tunes product descriptions for +20% sales. With thousands of SKUs, A/B testing product descriptions individually is a daunting task. SEATEXT simplifies this process by auto-generating and AB testing multiple description variants.',
                    'image' => 'picture-3.png',
                    'alt' => 'Product Descriptions'
                ],
                [
                    'title' => 'AI-Powered Mobile Optimization',
                    'description' => 'Automatically rewrite and optimize your website content for mobile users, improving conversions and readability. This AI feature helps increase mobile conversions by automatically adjusting website content for smaller screens.',
                    'image' => 'picture-4.png',
                    'alt' => 'Mobile Optimization'
                ]
            ];

            foreach ($products as $product) :
            ?>
                <div class="seatext-product-card">
                    <div class="card-content">
                        <h2><?php echo esc_html($product['title']); ?></h2>
                        <p><?php echo esc_html($product['description']); ?></p>
                    </div>
                    <img src="<?php echo esc_url(plugins_url('images/' . $product['image'], __FILE__)); ?>" alt="<?php echo esc_attr($product['alt']); ?>">
                </div>
            <?php endforeach; ?>
        </div>
    </div>
    <?php
    
    // Register and enqueue the inline script
    wp_register_script('seatext-admin-script', '', [], '', true);
    wp_enqueue_script('seatext-admin-script');
    
    $inline_script = "
        document.addEventListener('DOMContentLoaded', function() {
            var buttons = document.querySelectorAll('.seatext-button');
            buttons.forEach(function(button) {
                button.addEventListener('click', function() {
                    var url = this.getAttribute('data-url');
                    var seatextWindow = window.open(url, 'SeatextWindow', 'fullscreen=yes,menubar=no,toolbar=no,location=no,status=no');
                    if (seatextWindow) {
                        seatextWindow.moveTo(0,0);
                        seatextWindow.resizeTo(screen.width, screen.height);
                    } else {
                        alert('Please allow pop-ups for this website to open your Seatext account.');
                    }
                });
            });
        });
    ";
    
    wp_add_inline_script('seatext-admin-script', $inline_script);
}